@@ -77,7 +77,7 @@ sub run {
             my($h, $p, $opt) = split /:/, $listen, 3;
             $listen{host} = $h if $h;
             $listen{port} = $p;
-            $listen{proto} = 'ssl' if 'ssl' eq lc $opt;
+            $listen{proto} = 'ssl' if defined $opt && lc $opt eq 'ssl';
         } else {
             %listen = (
                 host  => 'localhost',
@@ -234,6 +234,7 @@ sub process_request {
             'psgix.io'          => $conn,
             'psgix.input.buffered' => Plack::Util::TRUE,
             'psgix.harakiri' => Plack::Util::TRUE,
+            'psgix.informational' => sub { _write_informational($conn, @_) },
         };
 
         # Parse headers
@@ -301,7 +302,7 @@ sub process_request {
 
         if ( $self->{client}->{keepalive} ) {
             # If we still have data in the input buffer it may be a pipelined request
-            if ( $self->{client}->{inputbuf} ) {
+            if ( $self->{client}->{inputbuf} ne '' ) {
                 if ( $self->{client}->{inputbuf} =~ /^(?:GET|HEAD)/ ) {
                     if ( DEBUG ) {
                         warn "Pipelined GET/HEAD request in input buffer: "
@@ -344,7 +345,7 @@ sub _read_headers {
             # Do we have a full header in the buffer?
             # This is before sysread so we don't read if we have a pipelined request
             # waiting in the buffer
-            last if defined $self->{client}->{inputbuf} && $self->{client}->{inputbuf} =~ /$CR?$LF$CR?$LF/s;
+            last if $self->{client}->{inputbuf} ne '' && $self->{client}->{inputbuf} =~ /$CR?$LF$CR?$LF/s;
 
             # If not, read some data
             my $read = sysread $self->{server}->{client}, my $buf, CHUNKSIZE;
@@ -404,7 +405,7 @@ sub _prepare_env {
     my($self, $env) = @_;
 
     my $get_chunk = sub {
-        if ($self->{client}->{inputbuf}) {
+        if ($self->{client}->{inputbuf} ne '') {
             my $chunk = delete $self->{client}->{inputbuf};
             return ($chunk, length $chunk);
         }
@@ -579,6 +580,20 @@ sub _syswrite {
     }
 }
 
+sub _write_informational {
+    my ($conn, $code, $headers) = @_;
+    my $message = HTTP::Status::status_message($code);
+    my @lines = "HTTP/1.1 $code $message";
+    for (my $i = 0; $i < @$headers; $i += 2) {
+        my $k = $headers->[$i];
+        my $v = $headers->[$i + 1];
+        push @lines, "$k: $v" ;
+    }
+    _syswrite($conn, \join($CRLF, @lines, $CRLF));
+
+    DEBUG && warn "[$$] Sent $code $message response\n";
+}
+
 sub post_client_connection_hook {
     my $self = shift;
     if ($self->{client}->{harakiri}) {
